@@ -1,11 +1,11 @@
 from PyProto.eventloop import Exceptions
-from PyProto.eventloop.EventLoop import EVENT_IN, EVENT_OUT, EVENT_EXCEPT
-try:
-    from select import select 
-except:
-    raise Exceptions.EventLoopUnsupportedException("select is not supported on your platform.")
+from PyProto.eventloop.Events import EVENT_IN, EVENT_OUT, EVENT_EXCEPT
+from PyProto.eventloop.engines import nullengine
 
-class EventEngine:
+try: from select import select 
+except: raise Exceptions.EventLoopUnsupportedException("select is not supported on your platform.")
+
+class SelectEventEngine(nullengine.NullEventEngine):
     def __init__(self):
         # :(
         self.fdlist = {}
